/*
** Module   : WebScreenDriver.java
** Abstract : web screen drivers contracts.
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 MAG 20131218 Created initial version.
** 002 CA  20140214 Changed to allow explicit host and port.
** 003 MAG 20140217 Add shutdown server method.
*/

package com.goldencode.p2j.ui.client.chui.driver.web;

import com.goldencode.p2j.main.*;

/**
 * Web screen drivers contract. 
 * Should be implemented by drivers having an embedded server. 
 *
 * @author mag
 * 
 */
public interface WebScreenDriver
{
   /**
    * Startup the embedded server using server KeyStore to build 
    * the server SSL context.
    * 
    * @param   keyStore
    *          The exported server KeyStore. 
    * @param   port
    *          An explicit port to start the web server or 0 to let the OS assign one.
    * @param   host
    *          An explicit host to start the web server or {@code null} to use the server's host.
    */
   public String startupServer(ServerKeyStore keyStore, String host, int port);

   /**
    * Shutdown embedded server.
    */   
   public void shutdownServer();

   /**
    * Get server URI
    * 
    * @return  A string representing the server URI.
    */
   public String getServerURI();
}
